@@ -41,3 +41,10 @@ class InvalidPricingConfigError(ConfigurationError):
     def __init__(self):
         message = "Either token_prices or character_prices must be set"
         super().__init__(message)
+
+
+class ProviderNotFoundError(Exception):
+    def __init__(self, provider_id: str):
+        self.provider_id = provider_id
+        message = f"Provider '{provider_id}' not found"
+        super().__init__(message)
