@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from collections.abc import Iterator, Sequence
-from typing import assert_never
+from collections.abc import Sequence
+from typing import TYPE_CHECKING, assert_never
 
 from loguru import logger
 from pydantic import BaseModel, Field
@@ -9,6 +9,9 @@ from pydantic import BaseModel, Field
 from no_llm import ModelCapability, ModelConfiguration, ModelParameters, ModelRegistry
 from no_llm.errors import ModelNotFoundError
 
+if TYPE_CHECKING:
+    from collections.abc import Iterator
+
 
 class ModelPreset(BaseModel):
     models: Sequence[str | ModelPreset] = Field(description="List of model IDs")
