@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from typing import Literal
+from urllib.parse import urljoin
 
 import httpx
 from loguru import logger
@@ -25,11 +26,14 @@ class AnthropicProvider(ProviderConfiguration):
     )
     base_url: str | None = Field(default=None, description="Optional base URL override")
 
-    def test(self) -> bool:
+    async def test(self) -> bool:
         try:
-            with httpx.Client() as client:
-                response = client.get(
-                    "https://api.anthropic.com/v1/models",
+            base_url = str(self.base_url)
+            if not base_url.endswith("/"):
+                base_url += "/"
+            async with httpx.AsyncClient() as client:
+                response = await client.get(
+                    urljoin(base_url, "models"),
                     headers={"Authorization": f"Bearer {self.api_key!s}"},
                 )
                 return response.status_code == 200
