@@ -1,5 +1,6 @@
-from collections.abc import Iterator
-from typing import Literal
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Literal
 
 from pydantic import Field, PrivateAttr
 from pydantic_ai.providers.bedrock import BedrockProvider as PydanticBedrockProvider
@@ -7,6 +8,9 @@ from pydantic_ai.providers.bedrock import BedrockProvider as PydanticBedrockProv
 from no_llm.providers.config import ProviderConfiguration
 from no_llm.providers.env_var import EnvVar
 
+if TYPE_CHECKING:
+    from collections.abc import Iterator
+
 
 class BedrockProvider(ProviderConfiguration):
     """AWS Bedrock provider configuration"""
@@ -15,7 +19,7 @@ class BedrockProvider(ProviderConfiguration):
     id: str = "bedrock"
     name: str = "Bedrock"
     region: EnvVar[str] = Field(default_factory=lambda: EnvVar[str]("$BEDROCK_REGION"), description="AWS region")
-    locations: list[str] = Field(default=["us-east-1"], description="AWS regions")
+    locations: list[str] = Field(default=["us-east-1"], min_length=1, description="AWS regions")
     _value: str | None = PrivateAttr(default=None)
 
     def iter(self) -> Iterator[ProviderConfiguration]:
