@@ -24,11 +24,14 @@ class OpenAIProvider(ProviderConfiguration):
     )
     base_url: str | None = Field(default="https://api.openai.com/v1/", description="Optional base URL override")
 
-    def test(self) -> bool:
+    async def test(self) -> bool:
         try:
-            with httpx.Client() as client:
-                response = client.get(
-                    urljoin(str(self.base_url), "models"), headers={"Authorization": f"Bearer {self.api_key!s}"}
+            base_url = str(self.base_url)
+            if not base_url.endswith("/"):
+                base_url += "/"
+            async with httpx.AsyncClient() as client:
+                response = await client.get(
+                    urljoin(base_url, "models"), headers={"Authorization": f"Bearer {self.api_key!s}"}
                 )
                 return response.status_code == 200
         except Exception as e:
