@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-from pathlib import Path
 from typing import TYPE_CHECKING
 
 from loguru import logger
@@ -10,6 +9,7 @@ from no_llm.providers.registry import ProviderRegistry
 
 if TYPE_CHECKING:
     from collections.abc import Iterator
+    from pathlib import Path
 
     from no_llm.models.config import ModelConfiguration
     from no_llm.providers.config import ProviderConfiguration
@@ -36,7 +36,7 @@ class Registry:
         model = self.models.get(model_id)
 
         # Get provider types that this model supports
-        compatible_provider_types = {provider.type for provider in model.providers}
+        compatible_provider_types = {provider().type for provider in model._compatible_providers}  # noqa: SLF001
         logger.debug(f"Model {model_id} supports provider types: {compatible_provider_types}")
 
         # Find all providers of compatible types
@@ -60,8 +60,7 @@ class Registry:
 
         # Find all models that support this provider type
         for model in self.models.list(only_valid=only_valid, only_active=only_active):
-            model_provider_types = {p.type for p in model.providers}
-            if provider.type in model_provider_types:
+            if type(provider) in model._compatible_providers:  # noqa: SLF001
                 logger.debug(f"Model {model.identity.id} is compatible with provider {provider_id}")
                 yield model
 
