@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from no_llm.providers import EnvVar, BedrockProvider
+from no_llm.providers import BedrockProvider, EnvVar
 
 
 def test_bedrock_provider_iter():
@@ -8,7 +8,7 @@ def test_bedrock_provider_iter():
         region=EnvVar[str]('$BEDROCK_REGION'),
         locations=['us-east-1', 'us-east-2']
     )
-    
+
     # Test iteration
     providers = list(provider.iter())
     assert len(providers) == 0
@@ -19,10 +19,10 @@ def test_bedrock_provider_current():
         region=EnvVar[str]('$BEDROCK_REGION'),
         locations=['us-east-1', 'us-east-2']
     )
-    
+
     # Test default current (first location)
     assert provider.current == 'us-east-1'
-    
+
     # Test after setting _value
     provider._value = 'us-east-2'
     assert provider.current == 'us-east-2'
@@ -33,7 +33,7 @@ def test_bedrock_provider_reset_variants():
         region=EnvVar[str]('$BEDROCK_REGION'),
         locations=['us-east-1', 'us-east-2']
     )
-    
+
     provider._value = 'us-east-2'
     provider.reset_variants()
     assert provider._value is None
