@@ -1,11 +1,15 @@
-from pathlib import Path
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 import pytest
 import yaml
-
+from no_llm._utils import find_yaml_file
 from no_llm.errors import ProviderNotFoundError
 from no_llm.providers.registry import ProviderRegistry
-from no_llm._utils import find_yaml_file
+
+if TYPE_CHECKING:
+    from pathlib import Path
 
 
 def create_test_provider_config(provider_type: str = "anthropic", provider_id: str | None = None) -> dict:
@@ -29,7 +33,7 @@ def config_dir(tmp_path) -> Path:
     return config_dir
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture
 def base_registry() -> ProviderRegistry:
     """Create a test registry without config directory"""
     return ProviderRegistry()
@@ -44,7 +48,7 @@ def registry(config_dir) -> ProviderRegistry:
 def test_registry_initialization_no_config():
     """Test registry initialization without config directory"""
     registry = ProviderRegistry()
-    
+
     assert registry._config_dir is None
     assert len(registry._providers) > 0  # Should have builtin providers
 
@@ -52,7 +56,7 @@ def test_registry_initialization_no_config():
 def test_registry_initialization_with_config(config_dir):
     """Test registry initialization with config directory"""
     registry = ProviderRegistry(config_dir)
-    
+
     assert registry._config_dir == config_dir
     assert len(registry._providers) > 0  # Should have builtin providers
 
@@ -70,12 +74,12 @@ def test_registry_provider_registration(base_registry: ProviderRegistry):
 def test_registry_provider_override(base_registry: ProviderRegistry):
     """Test provider override behavior"""
     initial_count = len(base_registry._providers)
-    
+
     config1 = create_test_provider_config("anthropic", "test-provider")
     config1["name"] = "First Provider"
     provider1 = base_registry._create_provider_from_config(config1)
-    
-    config2 = create_test_provider_config("anthropic", "test-provider")  
+
+    config2 = create_test_provider_config("anthropic", "test-provider")
     config2["name"] = "Second Provider"
     provider2 = base_registry._create_provider_from_config(config2)
 
@@ -102,22 +106,22 @@ def test_registry_get_providers_by_type_multiple(base_registry: ProviderRegistry
     # Start with builtin anthropic and openai
     initial_anthropic = len(list(base_registry.list_by_type("anthropic", only_valid=False, only_active=False)))
     initial_openai = len(list(base_registry.list_by_type("openai", only_valid=False, only_active=False)))
-    
+
     config1 = create_test_provider_config("anthropic", "anthropic-1")
     config2 = create_test_provider_config("anthropic", "anthropic-2")
     config3 = create_test_provider_config("openai", "openai-1")
-    
+
     provider1 = base_registry._create_provider_from_config(config1)
     provider2 = base_registry._create_provider_from_config(config2)
     provider3 = base_registry._create_provider_from_config(config3)
-    
+
     base_registry.register(provider1)
     base_registry.register(provider2)
     base_registry.register(provider3)
 
     anthropic_providers = list(base_registry.list_by_type("anthropic", only_valid=False, only_active=False))
     assert len(anthropic_providers) == initial_anthropic + 2
-    
+
     openai_providers = list(base_registry.list_by_type("openai", only_valid=False, only_active=False))
     assert len(openai_providers) == initial_openai + 1
 
@@ -132,7 +136,7 @@ def test_registry_get_nonexistent_provider(base_registry: ProviderRegistry):
     """Test getting non-existent provider raises error"""
     with pytest.raises(ProviderNotFoundError) as exc_info:
         base_registry.get("nonexistent")
-    
+
     assert exc_info.value.provider_id == "nonexistent"
 
 
@@ -143,7 +147,7 @@ def test_registry_remove_provider(base_registry: ProviderRegistry):
     base_registry.register(provider)
 
     base_registry.remove("test-anthropic")
-    
+
     with pytest.raises(ProviderNotFoundError):
         base_registry.get("test-anthropic")
 
@@ -152,7 +156,7 @@ def test_registry_remove_nonexistent_provider(base_registry: ProviderRegistry):
     """Test removing non-existent provider raises error"""
     with pytest.raises(ProviderNotFoundError) as exc_info:
         base_registry.remove("nonexistent")
-    
+
     assert exc_info.value.provider_id == "nonexistent"
 
 
@@ -160,7 +164,7 @@ def test_registry_list_providers_with_builtins_only(base_registry: ProviderRegis
     """Test listing providers when registry only has builtins"""
     providers = list(base_registry.list(only_valid=False))
     assert len(providers) >= 13  # Should have all builtin providers
-    
+
     # Check that we have expected builtin types (all from AnyProvider union)
     provider_types = {p.type for p in providers}
     expected_types = {"anthropic", "openai", "vertex", "groq", "mistral", "azure", "perplexity", "deepseek", "together", "openrouter", "grok", "fireworks", "bedrock"}
@@ -170,11 +174,11 @@ def test_registry_list_providers_with_builtins_only(base_registry: ProviderRegis
 def test_registry_list_providers_all(base_registry: ProviderRegistry):
     """Test listing all providers regardless of environment validity"""
     initial_count = len(list(base_registry.list(only_valid=False)))
-    
+
     config = create_test_provider_config("anthropic", "test-anthropic")
     provider = base_registry._create_provider_from_config(config)
     base_registry.register(provider)
-    
+
     providers = list(base_registry.list(only_valid=False))
     assert len(providers) == initial_count + 1
     assert provider in providers
@@ -215,12 +219,12 @@ def test_load_provider_from_yaml(tmp_path):
         "id": "anthropic",
         "name": "Anthropic",
     }
-    
+
     with open(provider_file, 'w') as f:
         yaml.dump(provider_config, f)
 
     registry = ProviderRegistry(config_dir)
-    
+
     provider = registry.get("anthropic")
     assert provider.type == "anthropic"
     assert provider.name == "Anthropic"
@@ -237,7 +241,7 @@ def test_load_provider_invalid_yaml(tmp_path):
     invalid_file.write_text("invalid: yaml: content: :")
 
     registry = ProviderRegistry(config_dir)
-    
+
     providers = list(registry.list())
     assert len(providers) > 0  # Should have builtin providers
 
@@ -254,12 +258,12 @@ def test_load_provider_invalid_config(tmp_path):
         "type": "nonexistent_provider_type",
         "name": "Bad Provider"
     }
-    
+
     with open(invalid_config, 'w') as f:
         yaml.dump(invalid_config_data, f)
 
     registry = ProviderRegistry(config_dir)
-    
+
     providers = list(registry.list())
     assert len(providers) > 0  # Should have builtin providers
 
@@ -281,7 +285,7 @@ def test_load_multiple_providers(tmp_path):
             }
         },
         {
-            "file": "openai.yml", 
+            "file": "openai.yml",
             "config": {
                 "type": "openai",
                 "id": "openai",
@@ -296,10 +300,10 @@ def test_load_multiple_providers(tmp_path):
             yaml.dump(provider_data["config"], f)
 
     registry = ProviderRegistry(config_dir)
-    
+
     providers = list(registry.list(only_valid=False))
     assert len(providers) >= 13  # Should have all builtin providers
-    
+
     provider_types = {provider.type for provider in providers}
     assert "anthropic" in provider_types
     assert "openai" in provider_types
@@ -313,8 +317,8 @@ def test_reload_configurations(tmp_path):
     providers_dir.mkdir()
 
     registry = ProviderRegistry(config_dir)
-    
-    assert len(list(registry.list(only_valid=True))) == 0
+
+    assert len(list(registry.list(only_valid=True))) == 1  # test provider
 
     provider_file = providers_dir / "anthropic.yml"
     provider_config = {
@@ -322,15 +326,15 @@ def test_reload_configurations(tmp_path):
         "id": "anthropic",
         "name": "Anthropic Test",
     }
-    
+
     with open(provider_file, 'w') as f:
         yaml.dump(provider_config, f)
 
     registry.reload()
-    
+
     providers = list(registry.list(only_valid=False))
     assert len(providers) >= 13  # Should have all builtin providers
-    
+
     # Find the anthropic provider and verify it was overridden
     anthropic_provider = registry.get("anthropic")
     assert anthropic_provider.type == "anthropic"
@@ -340,13 +344,13 @@ def test_reload_configurations(tmp_path):
 def test_create_provider_from_config():
     """Test creating provider from config dictionary"""
     registry = ProviderRegistry()
-    
+
     config = {
         "type": "anthropic",
         "id": "test-anthropic",
         "name": "Test Anthropic",
     }
-    
+
     provider = registry._create_provider_from_config(config)
     assert provider.type == "anthropic"
     assert provider.name == "Test Anthropic"
@@ -358,7 +362,7 @@ def test_registry_providers_directory_not_exists(tmp_path):
     config_dir.mkdir()
 
     registry = ProviderRegistry(config_dir)
-    
+
     providers = list(registry.list())
     assert len(providers) > 0  # Should have builtin providers
 
@@ -371,7 +375,7 @@ def test_registry_providers_directory_empty(tmp_path):
     providers_dir.mkdir()
 
     registry = ProviderRegistry(config_dir)
-    
+
     providers = list(registry.list(only_valid=False))
     assert len(providers) >= 13  # Should have all builtin providers
 
@@ -379,25 +383,25 @@ def test_registry_providers_directory_empty(tmp_path):
 def test_registry_comprehensive_builtin_behavior():
     """Test the complete builtin provider behavior"""
     registry = ProviderRegistry()
-    
+
     # Should have all providers from AnyProvider union
     all_providers = list(registry.list(only_valid=False))
     provider_types = {p.type for p in all_providers}
-    
+
     # All expected types from AnyProvider should be present
     expected_types = {
-        "anthropic", "openai", "vertex", "groq", "mistral", 
-        "azure", "perplexity", "deepseek", "together", 
+        "anthropic", "openai", "vertex", "groq", "mistral",
+        "azure", "perplexity", "deepseek", "together",
         "openrouter", "grok", "fireworks", "bedrock"
     }
     assert expected_types.issubset(provider_types)
-    
+
     # Each type should have exactly one builtin provider
     for provider_type in expected_types:
         providers_of_type = list(registry.list_by_type(provider_type, only_valid=False, only_active=False))
         assert len(providers_of_type) == 1
         assert providers_of_type[0].type == provider_type
-        
+
     # Verify we can access all by ID (same as type for builtins)
     for provider_type in expected_types:
         provider = registry.get(provider_type)
@@ -407,16 +411,16 @@ def test_registry_comprehensive_builtin_behavior():
 def test_provider_set_active_functionality(base_registry: ProviderRegistry):
     """Test setting provider active status"""
     provider_id = "anthropic"
-    
+
     # Provider should be active by default
     provider = base_registry.get(provider_id)
     assert provider.is_active is True
-    
+
     # Set provider to inactive
     base_registry.set_active(provider_id, False)
     provider = base_registry.get(provider_id)
     assert provider.is_active is False
-    
+
     # Set provider back to active
     base_registry.set_active(provider_id, True)
     provider = base_registry.get(provider_id)
@@ -427,7 +431,7 @@ def test_provider_set_active_nonexistent_provider(base_registry: ProviderRegistr
     """Test setting active status on non-existent provider raises error"""
     with pytest.raises(ProviderNotFoundError) as exc_info:
         base_registry.set_active("nonexistent", True)
-    
+
     assert exc_info.value.provider_id == "nonexistent"
 
 
@@ -438,22 +442,22 @@ def test_provider_listing_with_active_filter(base_registry: ProviderRegistry):
     all_providers = list(base_registry.list(only_valid=False, only_active=False))
     initial_active_count = len(active_providers)
     initial_total_count = len(all_providers)
-    
+
     # Deactivate one provider
     provider_id = "anthropic"
     base_registry.set_active(provider_id, False)
-    
+
     # Check filtering works
     active_providers = list(base_registry.list(only_valid=False, only_active=True))
     all_providers = list(base_registry.list(only_valid=False, only_active=False))
-    
+
     assert len(active_providers) == initial_active_count - 1
     assert len(all_providers) == initial_total_count  # Total unchanged
-    
+
     # Verify the deactivated provider is not in active list
     active_provider_ids = {p.id for p in active_providers}
     assert provider_id not in active_provider_ids
-    
+
     # But it should be in the all providers list
     all_provider_ids = {p.id for p in all_providers}
     assert provider_id in all_provider_ids
@@ -462,7 +466,7 @@ def test_provider_listing_with_active_filter(base_registry: ProviderRegistry):
 def test_provider_get_by_type_with_active_filter(base_registry: ProviderRegistry):
     """Test get_providers_by_type respects is_active filter"""
     provider_type = "anthropic"
-    
+
     # Should find active anthropic providers
     active_providers = list(base_registry.list_by_type(
         provider_type, only_valid=False, only_active=True
@@ -470,13 +474,13 @@ def test_provider_get_by_type_with_active_filter(base_registry: ProviderRegistry
     all_providers = list(base_registry.list_by_type(
         provider_type, only_valid=False, only_active=False
     ))
-    
+
     initial_active_count = len(active_providers)
     initial_total_count = len(all_providers)
-    
+
     # Deactivate the anthropic provider
     base_registry.set_active("anthropic", False)
-    
+
     # Check filtering works
     active_providers = list(base_registry.list_by_type(
         provider_type, only_valid=False, only_active=True
@@ -484,7 +488,7 @@ def test_provider_get_by_type_with_active_filter(base_registry: ProviderRegistry
     all_providers = list(base_registry.list_by_type(
         provider_type, only_valid=False, only_active=False
     ))
-    
+
     assert len(active_providers) == initial_active_count - 1
     assert len(all_providers) == initial_total_count
 
@@ -497,9 +501,9 @@ def test_provider_combined_active_and_valid_filtering(base_registry: ProviderReg
     providers_active_any = list(base_registry.list(only_valid=False, only_active=True))
     providers_any_valid = list(base_registry.list(only_valid=True, only_active=False))
     providers_any_any = list(base_registry.list(only_valid=False, only_active=False))
-    
+
     # Logical relationships should hold
     assert len(providers_active_valid) <= len(providers_active_any)
     assert len(providers_active_valid) <= len(providers_any_valid)
     assert len(providers_active_any) <= len(providers_any_any)
-    assert len(providers_any_valid) <= len(providers_any_any)
\ No newline at end of file
+    assert len(providers_any_valid) <= len(providers_any_any)
